context("")
test_that("The enrollment is", {
  suppressWarnings(RNGversion("3.5.0"))
  set.seed(200)
  check <- c(replicate(2, rpois(1, 1.5)), replicate(3, rpois(1, 2)))
  set.seed(200)
  expect_equal(as.numeric(table(enrollment(param = c(1.5, 2), 10, time = 2))), check)
  expect_error(enrollment(param = c(1.2, 2), N_total = 20))
  set.seed(52552)
  expect_equal(sum(enrollment(10, 100) == 0), 10)
  expect_error(enrollment(10, -100))
  expect_warning(enrollment(10, 100, 25))
  expect_error(enrollment(0, 100))
})
